@@ -147,6 +147,25 @@ void InsertLinkAfter (link_t *l, link_t *after);
 
 //============================================================================
 
+typedef struct vec_header_t {
+	size_t capacity;
+	size_t size;
+} vec_header_t;
+
+#define VEC_HEADER(v)			(((vec_header_t*)(v))[-1])
+
+#define VEC_PUSH(v,n)			do { Vec_Grow((void**)&(v), sizeof((v)[0]), 1); (v)[VEC_HEADER(v).size++] = (n); } while (0)
+#define VEC_SIZE(v)				((v) ? VEC_HEADER(v).size : 0)
+#define VEC_FREE(v)				Vec_Free((void**)&(v))
+#define VEC_CLEAR(v)			Vec_Clear((void**)&(v))
+
+void Vec_Grow (void **pvec, size_t element_size, size_t count);
+void Vec_Append (void **pvec, size_t element_size, const void *data, size_t count);
+void Vec_Clear (void **pvec);
+void Vec_Free (void **pvec);
+
+//============================================================================
+
 extern	qboolean		host_bigendian;
 
 extern	short	(*BigShort) (short l);
@@ -221,7 +240,14 @@ extern int q_vsnprintf(char *str, size_t size, const char *format, va_list args)
 extern	char		com_token[1024];
 extern	qboolean	com_eof;
 
+typedef enum
+{
+	CPE_NOTRUNC,		// return parse error in case of overflow
+	CPE_ALLOWTRUNC		// truncate com_token in case of overflow
+} cpe_mode;
+
 const char *COM_Parse (const char *data);
+const char *COM_ParseEx (const char *data, cpe_mode mode);
 
 
 extern	int		com_argc;
