@@ -449,7 +449,8 @@ byte *Image_LoadPCX (FILE *f, int *width, int *height)
 
 	start = ftell (f); //save start of file (since we might be inside a pak file, SEEK_SET might not be the start of the pcx)
 
-	fread(&pcx, sizeof(pcx), 1, f);
+	if (!fread(&pcx, sizeof(pcx), 1, f))
+		Sys_Error ("Failed reading header from '%s'", loadfilename);
 	pcx.xmin = (unsigned short)LittleShort (pcx.xmin);
 	pcx.ymin = (unsigned short)LittleShort (pcx.ymin);
 	pcx.xmax = (unsigned short)LittleShort (pcx.xmax);
@@ -472,7 +473,8 @@ byte *Image_LoadPCX (FILE *f, int *width, int *height)
 
 	//load palette
 	fseek (f, start + com_filesize - 768, SEEK_SET);
-	fread (palette, 1, 768, f);
+	if (!fread (palette, 768, 1, f))
+		Sys_Error ("Failed reading palette from '%s'", loadfilename);
 
 	//back to start of image data
 	fseek (f, start + sizeof(pcx), SEEK_SET);
