@@ -73,12 +73,12 @@ typedef struct entity_s
 	int						dlightbits;
 
 // FIXME: could turn these into a union
-	int						trivial_accept;
 	struct mnode_s			*topnode;		// for bmodels, first world node
 											//  that splits bmodel, or NULL if
 											//  not split
 
 	byte					alpha;			//johnfitz -- alpha
+	byte					scale;
 	byte					lerpflags;		//johnfitz -- lerping
 	float					lerpstart;		//johnfitz -- animation lerping
 	float					lerptime;		//johnfitz -- animation lerping
@@ -174,4 +174,3 @@ void D_InitCaches (void *buffer, int size);
 void R_SetVrect (vrect_t *pvrect, vrect_t *pvrectin, int lineadj);
 
 #endif	/* _QUAKE_RENDER_H */
-
