@@ -29,6 +29,7 @@
 
 /* headers for individual codecs */
 #include "snd_mikmod.h"
+#include "snd_modplug.h"
 #include "snd_xmp.h"
 #include "snd_umx.h"
 #include "snd_wave.h"
@@ -66,6 +67,9 @@ void S_CodecInit (void)
 #ifdef USE_CODEC_UMX
 	S_CodecRegister(&umx_codec);
 #endif
+#ifdef USE_CODEC_MODPLUG
+	S_CodecRegister(&modplug_codec);
+#endif
 #ifdef USE_CODEC_MIKMOD
 	S_CodecRegister(&mikmod_codec);
 #endif
