@@ -315,6 +315,11 @@ CLIENT SPAWNING
 ==============================================================================
 */
 
+static qboolean SV_IsLocalClient (client_t *client)
+{
+	return Q_strcmp (NET_QSocketGetAddressString (client->netconnection), "LOCAL") == 0;
+}
+
 /*
 ================
 SV_SendServerinfo
@@ -375,7 +380,7 @@ void SV_SendServerinfo (client_t *client)
 	MSG_WriteByte (&client->message, svc_signonnum);
 	MSG_WriteByte (&client->message, 1);
 
-	client->sendsignon = true;
+	client->sendsignon = PRESPAWN_FLUSH;
 	client->spawned = false;		// need prespawn, spawn, etc
 }
 
@@ -1138,6 +1143,34 @@ void SV_SendClientMessages (void)
 					SV_SendNop (host_client);
 				continue;	// don't send out non-signon messages
 			}
+			if (host_client->sendsignon == PRESPAWN_SIGNONBUFS)
+			{
+				qboolean local = SV_IsLocalClient (host_client);
+				while (host_client->signonidx < sv.num_signon_buffers)
+				{
+					sizebuf_t *signon = sv.signon_buffers[host_client->signonidx];
+					if (host_client->message.cursize + signon->cursize > host_client->message.maxsize)
+						break;
+					SZ_Write (&host_client->message, signon->data, signon->cursize);
+					host_client->signonidx++;
+					// only send multiple buffers at once when playing locally,
+					// otherwise we send one signon at a time to avoid overflowing
+					// the datagram buffer for clients using a lower limit (e.g. 32000 in QS)
+					if (!local)
+						break;
+				}
+				if (host_client->signonidx == sv.num_signon_buffers)
+					host_client->sendsignon = PRESPAWN_SIGNONMSG;
+			}
+			if (host_client->sendsignon == PRESPAWN_SIGNONMSG)
+			{
+				if (host_client->message.cursize + 2 < host_client->message.maxsize)
+				{
+					MSG_WriteByte (&host_client->message, svc_signonnum);
+					MSG_WriteByte (&host_client->message, 2);
+					host_client->sendsignon = PRESPAWN_FLUSH;
+				}
+			}
 		}
 
 		// check for an overflowed message.  Should only happen
@@ -1167,7 +1200,8 @@ void SV_SendClientMessages (void)
 					SV_DropClient (true);	// if the message couldn't send, kick off
 				SZ_Clear (&host_client->message);
 				host_client->last_message = realtime;
-				host_client->sendsignon = false;
+				if (host_client->sendsignon == PRESPAWN_FLUSH)
+					host_client->sendsignon = PRESPAWN_DONE;
 			}
 		}
 	}
@@ -1186,6 +1220,37 @@ SERVER SPAWNING
 ==============================================================================
 */
 
+#define SIGNON_SIZE		31500 // QS has a MAX_DATAGRAM of 32000, try to play nice
+
+/*
+================
+SV_AddSignonBuffer
+================
+*/
+static void SV_AddSignonBuffer (void)
+{
+	sizebuf_t *sb;
+	if (sv.num_signon_buffers >= MAX_SIGNON_BUFFERS)
+		Host_Error ("SV_AddSignonBuffer overflow\n");
+
+	sb = (sizebuf_t *) Hunk_AllocName (sizeof (sizebuf_t) + SIGNON_SIZE, "signon");
+	sb->data = (byte *)(sb + 1);
+	sb->maxsize = SIGNON_SIZE;
+	sv.signon_buffers[sv.num_signon_buffers++] = sb;
+	sv.signon = sb;
+}
+
+/*
+================
+SV_ReserveSignonSpace
+================
+*/
+void SV_ReserveSignonSpace (int numbytes)
+{
+	if (sv.signon->cursize + numbytes > sv.signon->maxsize)
+		SV_AddSignonBuffer ();
+}
+
 /*
 ================
 SV_ModelIndex
@@ -1284,45 +1349,47 @@ void SV_CreateBaseline (void)
 	//
 	// add to the message
 	//
+		SV_ReserveSignonSpace (35);
+
 		//johnfitz -- PROTOCOL_FITZQUAKE
 		if (bits)
-			MSG_WriteByte (&sv.signon, svc_spawnbaseline2);
+			MSG_WriteByte (sv.signon, svc_spawnbaseline2);
 		else
-			MSG_WriteByte (&sv.signon, svc_spawnbaseline);
+			MSG_WriteByte (sv.signon, svc_spawnbaseline);
 		//johnfitz
 
-		MSG_WriteShort (&sv.signon,entnum);
+		MSG_WriteShort (sv.signon,entnum);
 
 		//johnfitz -- PROTOCOL_FITZQUAKE
 		if (bits)
-			MSG_WriteByte (&sv.signon, bits);
+			MSG_WriteByte (sv.signon, bits);
 
 		if (bits & B_LARGEMODEL)
-			MSG_WriteShort (&sv.signon, svent->baseline.modelindex);
+			MSG_WriteShort (sv.signon, svent->baseline.modelindex);
 		else
-			MSG_WriteByte (&sv.signon, svent->baseline.modelindex);
+			MSG_WriteByte (sv.signon, svent->baseline.modelindex);
 
 		if (bits & B_LARGEFRAME)
-			MSG_WriteShort (&sv.signon, svent->baseline.frame);
+			MSG_WriteShort (sv.signon, svent->baseline.frame);
 		else
-			MSG_WriteByte (&sv.signon, svent->baseline.frame);
+			MSG_WriteByte (sv.signon, svent->baseline.frame);
 		//johnfitz
 
-		MSG_WriteByte (&sv.signon, svent->baseline.colormap);
-		MSG_WriteByte (&sv.signon, svent->baseline.skin);
+		MSG_WriteByte (sv.signon, svent->baseline.colormap);
+		MSG_WriteByte (sv.signon, svent->baseline.skin);
 		for (i=0 ; i<3 ; i++)
 		{
-			MSG_WriteCoord(&sv.signon, svent->baseline.origin[i], sv.protocolflags);
-			MSG_WriteAngle(&sv.signon, svent->baseline.angles[i], sv.protocolflags);
+			MSG_WriteCoord(sv.signon, svent->baseline.origin[i], sv.protocolflags);
+			MSG_WriteAngle(sv.signon, svent->baseline.angles[i], sv.protocolflags);
 		}
 
 		//johnfitz -- PROTOCOL_FITZQUAKE
 		if (bits & B_ALPHA)
-			MSG_WriteByte (&sv.signon, svent->baseline.alpha);
+			MSG_WriteByte (sv.signon, svent->baseline.alpha);
 		//johnfitz
 
 		if (bits & B_SCALE)
-			MSG_WriteByte (&sv.signon, svent->baseline.scale);
+			MSG_WriteByte (sv.signon, svent->baseline.scale);
 	}
 }
 
@@ -1392,7 +1459,7 @@ void SV_SpawnServer (const char *server)
 {
 	static char	dummy[8] = { 0,0,0,0,0,0,0,0 };
 	edict_t		*ent;
-	int			i;
+	int			i, signonsize;
 
 	// let's not have any servers with no name
 	if (hostname.string[0] == 0)
@@ -1457,9 +1524,7 @@ void SV_SpawnServer (const char *server)
 	sv.reliable_datagram.cursize = 0;
 	sv.reliable_datagram.data = sv.reliable_datagram_buf;
 
-	sv.signon.maxsize = sizeof(sv.signon_buf);
-	sv.signon.cursize = 0;
-	sv.signon.data = sv.signon_buf;
+	SV_AddSignonBuffer ();
 
 // leave slots at start for clients only
 	sv.num_edicts = svs.maxclients+1;
@@ -1537,8 +1602,12 @@ void SV_SpawnServer (const char *server)
 	SV_CreateBaseline ();
 
 	//johnfitz -- warn if signon buffer larger than standard server can handle
-	if (sv.signon.cursize > 8000-2) //max size that will fit into 8000-sized client->message buffer with 2 extra bytes on the end
-		Con_DWarning ("%i byte signon buffer exceeds standard limit of 7998 (max = %d).\n", sv.signon.cursize, sv.signon.maxsize);
+	for (i = 0, signonsize = 0; i < sv.num_signon_buffers; i++)
+		signonsize += sv.signon_buffers[i]->cursize;
+	if (signonsize > 64000-2)
+		Con_DWarning ("%i byte signon buffer exceeds QS limit of 63998.\n", signonsize);
+	else if (signonsize > 8000-2) //max size that will fit into 8000-sized client->message buffer with 2 extra bytes on the end
+		Con_DWarning ("%i byte signon buffer exceeds standard limit of 7998.\n", signonsize);
 	//johnfitz
 
 // send serverinfo to all connected clients
